@@ -18,8 +18,29 @@ import datetime
 import sqlite3
 import tqdm
 import tarfile, zipfile
+from . import constants as const
 
-CONFIG_DIFF_BASE_FOLDER_NAME = "resume_training_config_diffs_"
+
+def load_model_for_eval(model_factory, model_args, model_name, factory_kwargs, model_folder=None, device=None):
+    untrained_trunk = model_name in const.UNTRAINED_TRUNK_ALIASES
+    untrained_trunk_and_embedder = model_name in const.UNTRAINED_TRUNK_AND_EMBEDDER_ALIASES
+    trunk_model = model_factory.create(named_specs=model_args, subset="trunk", **factory_kwargs)
+    if untrained_trunk:
+        embedder_model = pml_cf.Identity()
+    else:
+        embedder_model = model_factory.create(named_specs=model_args, subset="embedder", **factory_kwargs)
+        if not untrained_trunk_and_embedder: 
+            if model_name in const.TRAINED_ALIASES:
+                _, model_name = pml_cf.latest_version(model_folder, best=True)
+            pml_cf.load_dict_of_models(
+                {"trunk": trunk_model, "embedder": embedder_model},
+                model_name,
+                model_folder,
+                device,
+                log_if_successful = True,
+                assert_success = True
+            )
+    return torch.nn.DataParallel(trunk_model), torch.nn.DataParallel(embedder_model)
 
 
 def move_optimizer_to_gpu(optimizer, device):
@@ -57,7 +78,7 @@ def latest_sub_experiment_epochs(sub_experiment_dir_dict):
 
 
 def get_sorted_config_diff_folders(config_folder):
-    full_base_path = os.path.join(config_folder, CONFIG_DIFF_BASE_FOLDER_NAME)
+    full_base_path = os.path.join(config_folder, const.CONFIG_DIFF_BASE_FOLDER_NAME)
     config_diff_folder_names = glob.glob("%s*"%full_base_path) 
     latest_epochs = []
     if len(config_diff_folder_names) > 0:
@@ -65,15 +86,14 @@ def get_sorted_config_diff_folders(config_folder):
             latest_epochs.append([c]+[int(x) for x in c.replace(full_base_path,"").split('_')])
         num_training_sets = len(latest_epochs[0])-1
         latest_epochs = sorted(latest_epochs, key=operator.itemgetter(*list(range(1, num_training_sets+1))))
-        return [x[0] for x in latest_epochs], [x[1:] for x in latest_epochs], num_training_sets
-    return [], [], 0
+        return [x[0] for x in latest_epochs], [x[1:] for x in latest_epochs]
+    return [], []
 
-def get_all_resume_training_config_diffs(config_folder, split_scheme_name):
-    config_diffs, latest_epochs, num_training_sets = get_sorted_config_diff_folders(config_folder)
-    if num_training_sets > 1:
-        split_scheme_names = ["%s%d"%(split_scheme_name,i) for i in range(num_training_sets)]
-    else:
-        split_scheme_names = [split_scheme_name]
+def get_all_resume_training_config_diffs(config_folder, split_manager):
+    config_diffs, latest_epochs = get_sorted_config_diff_folders(config_folder)
+    if len(config_diffs) == 0:
+        return {}
+    split_scheme_names = [split_manager.get_split_scheme_name(i) for i in range(len(latest_epochs[0]))]
     resume_training_dict = {}
     for i, k in enumerate(config_diffs):
         resume_training_dict[k] = {split_scheme:epoch for (split_scheme,epoch) in zip(split_scheme_names, latest_epochs[i])}
@@ -83,7 +103,7 @@ def get_all_resume_training_config_diffs(config_folder, split_scheme_name):
 def save_config_files(config_folder, dict_of_yamls, resume_training, latest_epochs):
     makedir_if_not_there(config_folder)
     new_dir = None
-    existing_config_diff_folders, _, _ = get_sorted_config_diff_folders(config_folder)
+    existing_config_diff_folders, _ = get_sorted_config_diff_folders(config_folder)
 
     for config_name, config_dict in dict_of_yamls.items():
         fname = os.path.join(config_folder, '%s.yaml'%config_name)
@@ -102,7 +122,7 @@ def save_config_files(config_folder, dict_of_yamls, resume_training, latest_epoc
                     yaml_diff[k] = v
 
             if yaml_diff != {}:
-                new_dir = os.path.join(config_folder, CONFIG_DIFF_BASE_FOLDER_NAME + '_'.join([str(epoch) for epoch in latest_epochs]))
+                new_dir = os.path.join(config_folder, const.CONFIG_DIFF_BASE_FOLDER_NAME + '_'.join([str(epoch) for epoch in latest_epochs]))
                 makedir_if_not_there(new_dir)
                 fname = os.path.join(new_dir, '%s.yaml' %config_name)
                 write_yaml(fname, yaml_diff, 'a')
@@ -157,4 +177,29 @@ def extract_progress(compressed_obj):
 def if_str_convert_to_singleton_list(input):
     if isinstance(input, str):
         return [input]
-    return input
\ No newline at end of file
+    return input
+
+def first_key_of_dict(input):
+    return list(input.keys())[0]
+
+def first_val_of_dict(input):
+    return input[first_key_of_dict(input)]
+
+
+def get_attr_and_try_as_function(input_object, input_attr):
+    attr = getattr(input_object, input_attr)
+    try:
+        return attr()
+    except TypeError:
+        return attr
+
+
+def get_eval_record_name_dict(hooks, tester, split_names=None):
+    prefix = hooks.record_group_name_prefix 
+    hooks.record_group_name_prefix = "" #temporary
+    if split_names is None:
+        non_meta = {"base_record_group_name": hooks.base_record_group_name(tester)}
+    else:
+        non_meta = {k:hooks.record_group_name(tester, k) for k in split_names}
+    hooks.record_group_name_prefix = prefix
+    return non_meta
\ No newline at end of file
